class Point():
    def __init__(self, latitude, longitude) -> None:

        try:
            self.latitude = latitude
            self.longitude = longitude

            if type(latitude) != float:
                self.latitude = float(latitude)

            if type(longitude) != float:
                self.longitude = float(longitude)

        except ValueError:
            print("Unable to convert.")
            self.latitude = 0.0
            self.longitude = 0.0

    def printPoints(self):
        print([self.latitude, self.longitude])


import math
from geodistance.point import Point

def calculate_distance(pointA: Point, pointB: Point, unit: str = "km", result_decimal: int = 4):

    if type(pointA) == Point and type(pointB) == Point:

        if unit == "m":
            EARTH_RADIUS = 6371 * 1000
        else:
            EARTH_RADIUS = 6371

        dLat = math.radians(pointB.latitude - pointA.latitude)
        dLng = math.radians(pointB.longitude - pointA.longitude)

        a = math.sin(dLat / 2) * math.sin(dLat / 2) + \
            math.cos(math.radians(pointA.latitude)) * \
            math.cos(math.radians(pointB.latitude)) * \
            math.sin(dLng / 2) * math.sin(dLng / 2)

        c = 2 * math.atan2(math.sqrt(a), math.sqrt(1 - a))

        return round(number = EARTH_RADIUS * c, ndigits = result_decimal)

    else:
        print("Invalid input value")



from point import Point
from main import calculate_distance

point1 = Point(41.19,65.85)
point2 = Point(29.19,16.85)
print(calculate_distance(point1,point2))

point1 = Point(3,3)
point2 = Point(6,12)
print(calculate_distance(point1,point2, "m"))

print(calculate_distance(5,point2, "m"))
